@@ -5,9 +5,13 @@
 
 ;; Author: Shen, Jen-Chieh <jcs090218@gmail.com>
 ;; URL: https://github.com/jcs-elpa/define-it
-;; Package-Version: 20260101.558
-;; Package-Revision: f33effcfcd4e
-;; Package-Requires: ((emacs "25.1") (s "1.12.0") (popup "0.5.3") (pos-tip "0.4.6") (posframe "1.1.7") (define-word "0.1.0") (google-translate "0.11.18") (wiki-summary "0.1"))
+;; Package-Version: 20260214.1857
+;; Package-Revision: 094c2dbe3fac
+;; Package-Requires: ((emacs "25.1") (s "1.12.0")
+;;                    (popup "0.5.3") (pos-tip "0.4.6") (posframe "1.1.7")
+;;                    (define-word "0.1.0")
+;;                    (google-translate "0.11.18")
+;;                    (wiki-summary "0.1"))
 ;; Keywords: convenience dictionary explanation search wiki
 
 ;; This file is NOT part of GNU Emacs.
@@ -34,9 +38,11 @@
 
 (require 'cl-lib)
 (require 'dom)
-(require 's)
+(require 'face-remap)
 (require 'subr-x)
 
+(require 's)
+
 (require 'pos-tip)
 (require 'popup)
 (require 'posframe)
